==> haskell-monad-dijkstra-0.1.1.5-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-KTB0DWkAt08FcXvIUhdqZA
key:                  monad-dijkstra-0.1.1.5-KTB0DWkAt08FcXvIUhdqZA
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  8aed64c13d357b2feef0cb1a843c77c2
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-KTB0DWkAt08FcXvIUhdqZA
depends:
    base-4.17.2.1 containers-0.6.7 free-5.2-1wZQftGsV1RDzldpkXHd
    mtl-2.2.2 psqueues-0.2.8.2-G1qNYYyKlMv2YmbUmkz1pg
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-dijkstra-0.1.1.5-180-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-GUfO2frXBlqBDvDyXOFNma
key:                  monad-dijkstra-0.1.1.5-GUfO2frXBlqBDvDyXOFNma
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  facf926649df6285a50399d58f0c382f
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-GUfO2frXBlqBDvDyXOFNma
depends:
    base-4.17.2.1 containers-0.6.7 free-5.2-LavBzzjIwTh2GJScdhp5qt
    mtl-2.2.2 psqueues-0.2.8.2-Faq2x2S7WnDAAtgzdAODJJ
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
